@@ -34,11 +34,16 @@ public class FreeTTSSpeaker extends UnknownImpl implements SpeakerOperations {
 
 		/* Cache current speech parameters */
 
-		pitch = v.getPitch();
+		pitch = v.getPitch() ;
 		rate = v.getRate();
 		volume = v.getVolume();
 	}
-	
+
+        /* called when refcount reaches 0 */
+        protected void destroy () {
+	        driver.unref ();
+	}
+
 	public org.GNOME.Speech.Parameter[] getSupportedParameters () {
 		Parameter[] parameters = new Parameter[3];
 		parameters[0] = new Parameter ("pitch",0.0, pitch, 1000, false);
